==> kendo-vue-listbox-5.0.1.tgz: package/README.md <==
<a href="https://www.telerik.com/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox&utm_content=banner" target="_blank">
<img src="https://www.telerik.com/kendo-vue-ui/components/npm-banner.svg" alt="Kendo UI for Vue NPM Banner">
</a>

# Kendo UI for Vue ListBox Component for Vue

> **Important**
> * This package is а part of [Kendo UI for Vue](https://www.telerik.com/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)&mdash;a commercial UI library.
> * You will need to install a license key when adding the package to your project. For more information, please refer to the [Kendo UI for Vue My License page](https://www.telerik.com/kendo-vue-ui/components/my-license/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox).
> * To receive a license key, you need to either [purchase a license](https://www.telerik.com/kendo-vue-ui/pricing?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox) or register for a [free trial](https://www.telerik.com/try/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox). Doing so indicates that you [accept the Kendo UI for Vue License Agreement](https://www.telerik.com/purchase/license-agreement/progress-kendovue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox).
> * The 30-day free trial gives you access to all the Kendo UI for Vue components and their full functionality. Additionally, for the period of your license, you get access to our legendary technical support provided directly by the Kendo UI for Vue dev team!
>
> [Start using Kendo UI for Vue](https://www.telerik.com/try/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox) and speed up your development process!

The [Vue ListBox](https://www.telerik.com/kendo-vue-ui/listbox), part of Kendo UI for Vue, enables you to display a list of items and manage the data between multiple lists.

## Vue ListBox

> Historically, all Kendo UI for Vue Native components support both **Vue 2** and **Vue 3**, however, Vue 2 is currently in its end-of-support phase till Nov 2024. After our last major release for 2024, Vue 2 will no longer be supported in the new versions of the Kendo UI for Vue components. Please check our [Vue 2 End of Support article](https://www.telerik.com/kendo-vue-ui/components/vue2-deprecation/) for more details.

Among the features which the Kendo UI for Vue ListBox component delivers are:

* [Drag and Drop](https://www.telerik.com/kendo-vue-ui/components/listbox/drag-and-drop/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)&mdash;Supports drag and drop items within the same list to reorder them or to move them between lists.
* [Custom Items](https://www.telerik.com/kendo-vue-ui/components/listbox/customization/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)&mdash;You can customize how the items of the ListBox are rendered and its toolbar button and position.
* [Multiple List](https://www.telerik.com/kendo-vue-ui/components/listbox/multiple-lists/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)&mdash; Multiple ListBox components can be connected to allow moving an item into different states.
* [Selection](https://www.telerik.com/kendo-vue-ui/components/listbox/selection/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)&mdash;You can select single on multiple item from the ListBox.
* [Theme support](https://www.telerik.com/kendo-vue-ui/components/styling/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)&mdash;The Kendo UI for Vue ListBox, as well as all 100+ components in the Kendo UI for Vue suite, are styled in four polished themes (Bootstrap, Material, Default and Fluent) and can be further customized to match your specific design guidelines.

## Support Options

For any issues you might encounter while working with the Kendo UI for Vue ListBox, use any of the available support channels:

* Industry-leading technical support&mdash;Kendo UI for Vue paid license holders and users with an active (free) trial license can take advantage of our outstanding customer support. To submit a ticket, use [the dedicated Kendo UI for Vue support system](https://www.telerik.com/account/support-tickets?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listview).
* Product forums&mdash;The [Kendo UI for Vue forums](https://www.telerik.com/forums/kendo-ui-vue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listview) are part of the free support you can get from the community and from the Kendo UI for Vue team.
* Feedback portal&mdash;The [Kendo UI for Vue feedback portal](https://feedback.telerik.com/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox) is where you can request and vote for new features to be added.

## Resources

* [Getting Started with Kendo UI for Vue](https://www.telerik.com/kendo-vue-ui/components/getting-started/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [Get Started with the Kendo UI for Vue ListBox](https://www.telerik.com/kendo-vue-ui/components/listbox/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [API Reference of the Kendo UI for Vue ListBox](https://www.telerik.com/kendo-vue-ui/components/listbox/api/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [Kendo UI for Vue Roadmap](https://www.telerik.com/support/whats-new/kendo-vue-ui/roadmap?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [Blogs](https://www.telerik.com/blogs/tag/vue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [Demos, documentation, and component reference](https://www.telerik.com/kendo-vue-ui/components/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [Kendo UI for Vue pricing and licensing](https://www.telerik.com/kendo-vue-ui/pricing?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [Changelog](https://www.telerik.com/kendo-vue-ui/components/changelogs/ui-for-vue/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)

High-level component overview pages

* [Vue ListBox Component](https://www.telerik.com/kendo-vue-ui/listbox)

*Copyright © 2023 Progress Software Corporation and/or its subsidiaries or affiliates. All Rights Reserved.*

*Progress, Telerik, and certain product names used herein are trademarks or registered trademarks of Progress Software Corporation and/or one of its subsidiaries or affiliates in the U.S. and/or other countries.*

==> kendo-vue-listbox-6.0.1.tgz: package/README.md <==
<a href="https://www.telerik.com/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox&utm_content=banner" target="_blank">
<img src="https://www.telerik.com/kendo-vue-ui/components/npm-banner.svg" alt="Kendo UI for Vue NPM Banner">
</a>

# Kendo UI for Vue ListBox Package

> **Important**
> * This package is а part of [Kendo UI for Vue](https://www.telerik.com/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)&mdash;a commercial UI library.
> * You will need to install a license key when adding the package to your project. For more information, please refer to the [Kendo UI for Vue My License page](https://www.telerik.com/kendo-vue-ui/components/my-license/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox).
> * To receive a license key, you need to either [purchase a license](https://www.telerik.com/kendo-vue-ui/pricing?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox) or register for a [free trial](https://www.telerik.com/try/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox). Doing so indicates that you [accept the Kendo UI for Vue License Agreement](https://www.telerik.com/purchase/license-agreement/progress-kendovue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox).
> * The 30-day free trial gives you access to all the Kendo UI for Vue components and their full functionality. Additionally, for the period of your license, you get access to our legendary technical support provided directly by the Kendo UI for Vue dev team!
>
> [Start using Kendo UI for Vue](https://www.telerik.com/try/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox) and speed up your development process!

The [Vue ListBox](https://www.telerik.com/kendo-vue-ui/listbox), part of Kendo UI for Vue, enables you to display a list of items and manage the data between multiple lists.

## Vue ListBox

> Starting with **version 6.0.0**, Kendo UI for Vue Native components no longer support Vue 2. Please check our [Vue 2 End of Support article](https://www.telerik.com/kendo-vue-ui/components/vue2-deprecation/) for more details.

Among the features which the Kendo UI for Vue ListBox component delivers are:

* [Drag and Drop](https://www.telerik.com/kendo-vue-ui/components/listbox/drag-and-drop/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)&mdash;Supports drag and drop items within the same list to reorder them or to move them between lists.
* [Custom Items](https://www.telerik.com/kendo-vue-ui/components/listbox/customization/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)&mdash;You can customize how the items of the ListBox are rendered and its toolbar button and position.
* [Multiple List](https://www.telerik.com/kendo-vue-ui/components/listbox/multiple-lists/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)&mdash; Multiple ListBox components can be connected to allow moving an item into different states.
* [Selection](https://www.telerik.com/kendo-vue-ui/components/listbox/selection/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)&mdash;You can select single on multiple item from the ListBox.
* [Theme support](https://www.telerik.com/kendo-vue-ui/components/styling/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)&mdash;The Kendo UI for Vue ListBox, as well as all 100+ components in the Kendo UI for Vue suite, are styled in four polished themes (Bootstrap, Material, Default and Fluent) and can be further customized to match your specific design guidelines.

## Support Options

For any issues you might encounter while working with the Kendo UI for Vue ListBox, use any of the available support channels:

* Industry-leading technical support&mdash;Kendo UI for Vue paid license holders and users with an active (free) trial license can take advantage of our outstanding customer support. To submit a ticket, use [the dedicated Kendo UI for Vue support system](https://www.telerik.com/account/support-tickets?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listview).
* Product forums&mdash;The [Kendo UI for Vue forums](https://www.telerik.com/forums/kendo-ui-vue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listview) are part of the free support you can get from the community and from the Kendo UI for Vue team.
* Feedback portal&mdash;The [Kendo UI for Vue feedback portal](https://feedback.telerik.com/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox) is where you can request and vote for new features to be added.

## Resources

* [Getting Started with Kendo UI for Vue](https://www.telerik.com/kendo-vue-ui/components/getting-started/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [Get Started with the Kendo UI for Vue ListBox](https://www.telerik.com/kendo-vue-ui/components/listbox/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [API Reference of the Kendo UI for Vue ListBox](https://www.telerik.com/kendo-vue-ui/components/listbox/api/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [Kendo UI for Vue Roadmap](https://www.telerik.com/support/whats-new/kendo-vue-ui/roadmap?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [Blogs](https://www.telerik.com/blogs/tag/vue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [Demos, documentation, and component reference](https://www.telerik.com/kendo-vue-ui/components/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [Kendo UI for Vue pricing and licensing](https://www.telerik.com/kendo-vue-ui/pricing?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)
* [Changelog](https://www.telerik.com/kendo-vue-ui/components/changelogs/ui-for-vue/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-listbox)

High-level component overview pages

* [Vue ListBox Component](https://www.telerik.com/kendo-vue-ui/listbox)

*Copyright © 2024 Progress Software Corporation and/or its subsidiaries or affiliates. All Rights Reserved.*

*Progress, Telerik, and certain product names used herein are trademarks or registered trademarks of Progress Software Corporation and/or one of its subsidiaries or affiliates in the U.S. and/or other countries.*
